@@ -45,8 +45,8 @@ class ActionImpl : public QObject
     Q_OBJECT
 
 public:
-    ActionImpl(ClientImpl *client, Action *interface, const QString &path, const QString &description, QObject *parent = 0);
-    ~ActionImpl();
+    ActionImpl(ClientImpl *client, Action *interface, const QString &path, const QString &description, QObject *parent = nullptr);
+    ~ActionImpl() override;
 
     QString changeShortcut(const QString &shortcut);
     bool changeDescription(const QString &description);
