@@ -115,54 +115,71 @@
         <translation>Globální správa akcí</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="52"/>
+        <location filename="../main_window.ui" line="55"/>
         <source>Add ...</source>
         <translation>Přidat…</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="62"/>
+        <location filename="../main_window.ui" line="65"/>
         <source>Remove</source>
         <translation>Odstranit</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="72"/>
+        <location filename="../main_window.ui" line="75"/>
         <source>Modify ...</source>
         <translation>Změnit…</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="89"/>
+        <location filename="../main_window.ui" line="92"/>
         <source>Swap</source>
         <translation>Prohodit</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="115"/>
+        <location filename="../main_window.ui" line="118"/>
         <source>Multiple actions behaviour:</source>
         <translation>Chování při více akcích:</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="123"/>
+        <location filename="../main_window.ui" line="126"/>
         <source>First</source>
         <translation>První</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="128"/>
+        <location filename="../main_window.ui" line="131"/>
         <source>Last</source>
         <translation>Poslední</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="133"/>
+        <location filename="../main_window.ui" line="136"/>
         <source>None</source>
         <translation>Žádná</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="138"/>
+        <location filename="../main_window.ui" line="141"/>
         <source>All</source>
         <translation>Vše</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="176"/>
+        <location filename="../main_window.ui" line="166"/>
+        <source>Default</source>
+        <translation>Výchozí</translation>
+    </message>
+    <message>
+        <location filename="../main_window.ui" line="186"/>
         <source>Close</source>
         <translation>Zavřít</translation>
     </message>
+    <message>
+        <location filename="../main_window.cpp" line="187"/>
+        <source>Restore Default</source>
+        <translation>Vrátit na výchozí hodnoty</translation>
+    </message>
+    <message>
+        <location filename="../main_window.cpp" line="188"/>
+        <source>Your defined shortcuts will be removed.
+Do you want to proceed?</source>
+        <translation>Vámi určené klávesové zkratky budou odebrány.
+Opravdu to chcete?</translation>
+    </message>
 </context>
 </TS>
