@@ -115,54 +115,71 @@
         <translation>Visuotinių veiksmų tvarkytuvė</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="52"/>
+        <location filename="../main_window.ui" line="55"/>
         <source>Add ...</source>
         <translation>Pridėti ...</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="62"/>
+        <location filename="../main_window.ui" line="65"/>
         <source>Remove</source>
         <translation>Šalinti</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="72"/>
+        <location filename="../main_window.ui" line="75"/>
         <source>Modify ...</source>
         <translation>Keisti ...</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="89"/>
+        <location filename="../main_window.ui" line="92"/>
         <source>Swap</source>
         <translation>Apkeisti</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="115"/>
+        <location filename="../main_window.ui" line="118"/>
         <source>Multiple actions behaviour:</source>
         <translation>Kelių veiksmų elgsena:</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="123"/>
+        <location filename="../main_window.ui" line="126"/>
         <source>First</source>
         <translation>Pirmas</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="128"/>
+        <location filename="../main_window.ui" line="131"/>
         <source>Last</source>
         <translation>Paskutinis</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="133"/>
+        <location filename="../main_window.ui" line="136"/>
         <source>None</source>
         <translation>Nėra</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="138"/>
+        <location filename="../main_window.ui" line="141"/>
         <source>All</source>
         <translation>Visi</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="176"/>
+        <location filename="../main_window.ui" line="166"/>
+        <source>Default</source>
+        <translation>Numatytasis</translation>
+    </message>
+    <message>
+        <location filename="../main_window.ui" line="186"/>
         <source>Close</source>
         <translation>Užverti</translation>
     </message>
+    <message>
+        <location filename="../main_window.cpp" line="187"/>
+        <source>Restore Default</source>
+        <translation>Atkurti numatytąjį</translation>
+    </message>
+    <message>
+        <location filename="../main_window.cpp" line="188"/>
+        <source>Your defined shortcuts will be removed.
+Do you want to proceed?</source>
+        <translation>Jūsų apibrėžti spartieji klavišai bus pašalinti.
+Ar norite tęsti?</translation>
+    </message>
 </context>
 </TS>
