@@ -115,54 +115,71 @@
         <translation>Küresel Eylemler Yöneticisi</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="52"/>
+        <location filename="../main_window.ui" line="55"/>
         <source>Add ...</source>
         <translation>Ekle...</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="62"/>
+        <location filename="../main_window.ui" line="65"/>
         <source>Remove</source>
         <translation>Sil</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="72"/>
+        <location filename="../main_window.ui" line="75"/>
         <source>Modify ...</source>
         <translation>Düzenle ...</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="89"/>
+        <location filename="../main_window.ui" line="92"/>
         <source>Swap</source>
         <translation>Değiştir</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="115"/>
+        <location filename="../main_window.ui" line="118"/>
         <source>Multiple actions behaviour:</source>
         <translation>Çoklu eylem davranışı:</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="123"/>
+        <location filename="../main_window.ui" line="126"/>
         <source>First</source>
         <translation>Birinci</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="128"/>
+        <location filename="../main_window.ui" line="131"/>
         <source>Last</source>
         <translation>Sonuncu</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="133"/>
+        <location filename="../main_window.ui" line="136"/>
         <source>None</source>
         <translation>Hiçbiri</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="138"/>
+        <location filename="../main_window.ui" line="141"/>
         <source>All</source>
         <translation>Hepsi</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="176"/>
+        <location filename="../main_window.ui" line="166"/>
+        <source>Default</source>
+        <translation>Varsayılan</translation>
+    </message>
+    <message>
+        <location filename="../main_window.ui" line="186"/>
         <source>Close</source>
         <translation>Kapat</translation>
     </message>
+    <message>
+        <location filename="../main_window.cpp" line="187"/>
+        <source>Restore Default</source>
+        <translation>Varsayılanı Geri Yükle</translation>
+    </message>
+    <message>
+        <location filename="../main_window.cpp" line="188"/>
+        <source>Your defined shortcuts will be removed.
+Do you want to proceed?</source>
+        <translation>Belirlediğiniz kısayol silinecek.
+Devam etmek istiyor musunuz?</translation>
+    </message>
 </context>
 </TS>
