@@ -58,6 +58,7 @@ class NativeAdaptor;
 class DBusProxy;
 class BaseAction;
 class QDBusServiceWatcher;
+class QSettings;
 
 template<class Key>
 class QOrderedSet : public QMap<Key, Key>
@@ -73,12 +74,12 @@ class Core : public QThread, public LogTarget
 {
     Q_OBJECT
 public:
-    Core(bool useSyslog, bool minLogLevelSet, int minLogLevel, const QStringList &configFiles, bool multipleActionsBehaviourSet, MultipleActionsBehaviour multipleActionsBehaviour, QObject *parent = 0);
-    ~Core();
+    Core(bool useSyslog, bool minLogLevelSet, int minLogLevel, const QStringList &configFiles, bool multipleActionsBehaviourSet, MultipleActionsBehaviour multipleActionsBehaviour, QObject *parent = nullptr);
+    ~Core() override;
 
     bool ready() const { return mReady; }
 
-    virtual void log(int level, const char *format, ...) const;
+    void log(int level, const char *format, ...) const override;
 
 signals:
     void onShortcutGrabbed();
@@ -168,7 +169,7 @@ private:
 
     void wakeX11Thread();
 
-    void run();
+    void run() override;
 
     KeyCode remoteStringToKeycode(const QString &str);
     QString remoteKeycodeToString(KeyCode keyCode);
@@ -242,7 +243,6 @@ private:
     bool mAllowGrabMiscKeypad;
     bool mAllowGrabPrintable;
 
-    QString mConfigFile;
     bool mSaveAllowed;
 
     QTimer *mShortcutGrabTimeout;
